namespace elm { 
inline ::efl::eolian::return_traits<Elm_Dayselector_Day>::type Dayselector::week_start_get() const
{
   Elm_Dayselector_Day __return_value =  ::elm_obj_dayselector_week_start_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Dayselector_Day>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Dayselector::week_start_set( ::efl::eolian::in_traits<Elm_Dayselector_Day>::type day) const
{
    ::elm_obj_dayselector_week_start_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Dayselector_Day,  ::efl::eolian::in_traits<Elm_Dayselector_Day>::type>(day));
}
inline ::efl::eolian::return_traits< unsigned int>::type Dayselector::weekend_length_get() const
{
   unsigned int __return_value =  ::elm_obj_dayselector_weekend_length_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Dayselector::weekend_length_set( ::efl::eolian::in_traits< unsigned int>::type length) const
{
    ::elm_obj_dayselector_weekend_length_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(length));
}
inline ::efl::eolian::return_traits<Elm_Dayselector_Day>::type Dayselector::weekend_start_get() const
{
   Elm_Dayselector_Day __return_value =  ::elm_obj_dayselector_weekend_start_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Dayselector_Day>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Dayselector::weekend_start_set( ::efl::eolian::in_traits<Elm_Dayselector_Day>::type day) const
{
    ::elm_obj_dayselector_weekend_start_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Dayselector_Day,  ::efl::eolian::in_traits<Elm_Dayselector_Day>::type>(day));
}
inline ::efl::eolian::return_traits<  ::efl::eina::list< ::efl::eina::stringshare>>::type Dayselector::weekdays_names_get() const
{
   Eina_List * __return_value =  ::elm_obj_dayselector_weekdays_names_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::list< ::efl::eina::stringshare>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Dayselector::day_selected_set( ::efl::eolian::in_traits<Elm_Dayselector_Day>::type day,  ::efl::eolian::in_traits<bool>::type selected) const
{
    ::elm_obj_dayselector_day_selected_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Dayselector_Day,  ::efl::eolian::in_traits<Elm_Dayselector_Day>::type>(day)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(selected));
}
inline ::efl::eolian::return_traits<bool>::type Dayselector::day_selected_get( ::efl::eolian::in_traits<Elm_Dayselector_Day>::type day) const
{
   Eina_Bool __return_value =  ::elm_obj_dayselector_day_selected_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Dayselector_Day,  ::efl::eolian::in_traits<Elm_Dayselector_Day>::type>(day));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<Elm_Dayselector_Day>::type Dayselector::week_start_get() const
{
   Elm_Dayselector_Day __return_value =  ::elm_obj_dayselector_week_start_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Dayselector_Day>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Dayselector::week_start_set( ::efl::eolian::in_traits<Elm_Dayselector_Day>::type day) const
{
    ::elm_obj_dayselector_week_start_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Dayselector_Day,  ::efl::eolian::in_traits<Elm_Dayselector_Day>::type>(day));
}
inline ::efl::eolian::return_traits< unsigned int>::type Dayselector::weekend_length_get() const
{
   unsigned int __return_value =  ::elm_obj_dayselector_weekend_length_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Dayselector::weekend_length_set( ::efl::eolian::in_traits< unsigned int>::type length) const
{
    ::elm_obj_dayselector_weekend_length_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<unsigned int,  ::efl::eolian::in_traits< unsigned int>::type>(length));
}
inline ::efl::eolian::return_traits<Elm_Dayselector_Day>::type Dayselector::weekend_start_get() const
{
   Elm_Dayselector_Day __return_value =  ::elm_obj_dayselector_weekend_start_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Dayselector_Day>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Dayselector::weekend_start_set( ::efl::eolian::in_traits<Elm_Dayselector_Day>::type day) const
{
    ::elm_obj_dayselector_weekend_start_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Dayselector_Day,  ::efl::eolian::in_traits<Elm_Dayselector_Day>::type>(day));
}
inline ::efl::eolian::return_traits<  ::efl::eina::list< ::efl::eina::stringshare>>::type Dayselector::weekdays_names_get() const
{
   Eina_List * __return_value =  ::elm_obj_dayselector_weekdays_names_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::list< ::efl::eina::stringshare>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Dayselector::day_selected_set( ::efl::eolian::in_traits<Elm_Dayselector_Day>::type day,  ::efl::eolian::in_traits<bool>::type selected) const
{
    ::elm_obj_dayselector_day_selected_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Dayselector_Day,  ::efl::eolian::in_traits<Elm_Dayselector_Day>::type>(day)
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(selected));
}
inline ::efl::eolian::return_traits<bool>::type Dayselector::day_selected_get( ::efl::eolian::in_traits<Elm_Dayselector_Day>::type day) const
{
   Eina_Bool __return_value =  ::elm_obj_dayselector_day_selected_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Dayselector_Day,  ::efl::eolian::in_traits<Elm_Dayselector_Day>::type>(day));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline elm::Dayselector::operator ::elm::Dayselector() const { return *static_cast< ::elm::Dayselector const*>(static_cast<void const*>(this)); }
inline elm::Dayselector::operator ::elm::Dayselector&() { return *static_cast< ::elm::Dayselector*>(static_cast<void*>(this)); }
inline elm::Dayselector::operator ::elm::Dayselector const&() const { return *static_cast< ::elm::Dayselector const*>(static_cast<void const*>(this)); }
} }

